@@ -19,7 +19,7 @@ sub test_numericness {
     my %tests = (
         1	=> '1',            # num
 	0	=> '0',            # num
-  	'0xF00'	=> '0',            # str
+  	'0xF00'	=> $] >= 5.008 ? '0' : '3840',  # 5.6 num, >=5.8 str
 	'15e7'	=> '150000000',    # num
 	'15E7'	=> '150000000',    # num
 	"not 0"	=> '0',            # str
